<?php
/*
Plugin Name: Moving Your Blog
Plugin URI: http://rmarsh.com/2006/09/23/moving-your-blog/
Description: If you ever have to move your blog from one domain to another this plugin will redirect traffic for you so you don't lose your visitors or your Google rank. When you have activated the plugin visit the Options|Moving page to set the address of your new blog. Setting an address activates the redirection (301). Admin pages are exempt.
Author: Rob Marsh, SJ
Version: 1.0
Author URI: http://rmarsh.com/
*/

/*  Copyright 2006  Rob Marsh, SJ  (http://rmarsh.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/


//this is the routine that does all the work
function rrm_mover() {
	if (!is_admin()) {
		//work out if your old blog is in the root or in a subdirectory
		$url = get_bloginfo('url');
		$info = parse_url($url);
		$old_blog_subdir = $info['path'];
		// see which page has been requested
		$requested_page = $_SERVER['REQUEST_URI'];
		//strip off the subdirectory if necessary
		$pos = strpos($requested_page, $old_blog_subdir);
		if (!($pos === FALSE) && ($pos === 0)) {
			$requested_page = substr($requested_page, strlen($old_blog_subdir));
		}
		//create the new url
		$new_page = trim(get_option("new_blog_address")) . $requested_page;
		//do the redirect
		header("HTTP/1.1 301 Moved Permanently"); 
		header("Location: " . $new_page);
		header("Status: 301 Moved Permanently");
		exit(); 
	}
}

//we activate our redirection routine only if a new blog address has been set through the options page
if (trim(get_option("new_blog_address")) !== '') {
	add_action('template_redirect', 'rrm_mover');
}

/*
	the remaining code handles the options page for our plugin
*/

//where to install our options page
function rrm_mover_options() {
    global $wpdb;
    if (function_exists('add_options_page'))
        add_options_page('Moving Your Blog Options', 'Moving', 10, __FILE__, 'rrm_mover_panel');
}

//installing the options page
add_action('admin_menu', 'rrm_mover_options');

//the routine that draws the options page and saves the settings
function rrm_mover_panel() {
	//we have just one option to set
	//the initial value of '' is important since we only activate the redirection if a new value is set
    add_option('new_blog_address','','the address of your new blog');
	//if the options page is being updated we need to save the setting
    if ($_POST['action'] == 'update') {
		$new_addy = $_POST['new_blog_address'];
		//a blank value is left alone...
		if (trim($new_addy) !== '') {
			//... but we make sure other addresses have a proper 'http://' prefix
			$pos = strpos(strtolower($new_addy), 'http://');
			if (($pos === FALSE) || ($pos !== 0)) {
				$new_addy = 'http://' . $new_addy;
			} 
		}
		//finally we save the setting
        update_option('new_blog_address', $new_addy);
    }
    ?>
	<!--the following code displays the options page-->
    <div class="wrap">
        <h2 id="write-post">Moving Your Blog Options</h2>
        <p><strong>Moving Your Blog</strong> needs to know the address of your new blog, e.g., <em>myblog.com</em>, 
		or <em>myblog.com/mydir</em>, or <em>www.myblog.co.uk</em>.</p>
		<p>As soon as you update the address all requests for pages (except admin pages) at <em>this</em> blog will 
		be 	redirected to the new one. To cancel the redirection either delete the new address below or 
		deactivate the plugin.</p>
        <form method="post" action="<?php echo $_SERVER['PHP_SELF']; ?>?page=moving.php">
            <input type="hidden" name="action" value="update" />
            <fieldset class="options">
                <legend>Address of Your New Blog</legend>
				<input type="text" name="new_blog_address" value="<?php echo get_option("new_blog_address"); ?>" />
            </fieldset>
            <p class="submit"><input type="submit" value="Update Address &raquo;" name="Submit" /></p>
        </form>
    </div>
    <?            
}

?>